@@ -147,7 +147,7 @@ def add_drk_skills(skill_library):
         )
     )
     salted_earth_dot_drk = Skill(
-        name="_Salted Earth dot",
+        name="Salted Earth (dot)",
         is_GCD=False,
         damage_spec=DamageSpec(
             potency=50,
@@ -236,38 +236,25 @@ def add_drk_skills(skill_library):
             ),
         )
     )
-    _living_shadow = Skill(
-        name="_Living Shadow",
-        is_GCD=False,
-        damage_spec=DamageSpec(
-            potency=420, damage_class=DamageClass.PET, pet_job_mod_override=100
-        ),
-        status_effect_denylist=("Darkside", "Dragon Sight"),
-    )
-    _living_shadow_shadowbringer = Skill(
-        name="_Living Shadow Shadowbringer",
-        is_GCD=False,
-        damage_spec=DamageSpec(
-            potency=570, damage_class=DamageClass.PET, pet_job_mod_override=100
-        ),
-        status_effect_denylist=("Darkside", "Dragon Sight"),
-    )
-    _living_shadow_disesteem = Skill(
-        name="_Living Shadow Disesteem",
-        is_GCD=False,
-        damage_spec=DamageSpec(
-            potency=620, damage_class=DamageClass.PET, pet_job_mod_override=100
-        ),
-        status_effect_denylist=("Darkside", "Dragon Sight"),
-    )    
-    _living_shadow_follow_up_skills = (
-        _living_shadow,
-        _living_shadow,
-        _living_shadow_shadowbringer,
-        _living_shadow,
-        _living_shadow,
-        _living_shadow_disesteem,
-    )
+    ls_names_and_potency = [('Abyssal Drain (pet)',420),
+                            ('Plunge (pet)',420),
+                            ('Shadowbringer (pet)', 570),
+                            ('Edge of Shadow (pet)',420),
+                            ('Bloodspiller (pet)',420),                            
+                            ('Disesteem (pet)',620)]
+    
+    _living_shadow_follow_up_skills = []
+    for skill_name, potency in ls_names_and_potency:
+        sk = Skill(
+            name=skill_name,
+            is_GCD=False,
+            damage_spec=DamageSpec(
+                potency=potency, damage_class=DamageClass.PET, pet_job_mod_override=100
+            ),
+            status_effect_denylist=("Darkside",),        
+        )
+        _living_shadow_follow_up_skills.append(sk)
+ 
     _living_shadow_follow_ups = tuple(
         FollowUp(
             skill=_living_shadow_follow_up_skills[i],
@@ -283,7 +270,7 @@ def add_drk_skills(skill_library):
             is_GCD=False,
             follow_up_skills=_living_shadow_follow_ups,
             timing_spec=instant_timing_spec,
-            status_effect_denylist=("Darkside", "Dragon Sight"),
+            status_effect_denylist=("Darkside",),
         )
     )
 
