@@ -1,11 +1,11 @@
-from simulator.calcs.forced_crit_or_dh import ForcedCritOrDH
-from simulator.skills.skill_modifier import SkillModifier
-from simulator.sim_consts import SimConsts
-from simulator.stats import Stats
-from simulator.testing.test_class import TestClass
-from simulator.testing.create_test_skill_library import create_test_skill_library
-from simulator.timeline_builders.snapshot_and_application_events import SnapshotAndApplicationEvents
-from simulator.timeline_builders.rotation_builder import RotationBuilder
+from ama_xiv_combat_sim.simulator.calcs.forced_crit_or_dh import ForcedCritOrDH
+from ama_xiv_combat_sim.simulator.skills.skill_modifier import SkillModifier
+from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
+from ama_xiv_combat_sim.simulator.stats import Stats
+from ama_xiv_combat_sim.simulator.testing.test_class import TestClass
+from ama_xiv_combat_sim.simulator.testing.create_test_skill_library import create_test_skill_library
+from ama_xiv_combat_sim.simulator.timeline_builders.snapshot_and_application_events import SnapshotAndApplicationEvents
+from ama_xiv_combat_sim.simulator.timeline_builders.rotation_builder import RotationBuilder
 
 class TestRotationBuilder(TestClass):
   def __init__(self):
@@ -520,7 +520,7 @@ class TestRotationBuilder(TestClass):
                 (SnapshotAndApplicationEvents.EventTimes(7700, 8200), self.__skill_library.get_skill('Auto', self.__stats.job_class), SkillModifier(), [True, True]),
                 (SnapshotAndApplicationEvents.EventTimes(10280, 10780), self.__skill_library.get_skill('Auto', self.__stats.job_class), SkillModifier(), [True, True]),
                 (SnapshotAndApplicationEvents.EventTimes(12860, 13360), self.__skill_library.get_skill('Auto', self.__stats.job_class), SkillModifier(), [True, True]),
-                (SnapshotAndApplicationEvents.EventTimes(15440, 15940), self.__skill_library.get_skill('Auto', self.__stats.job_class), SkillModifier(), [True, True]),
+                (SnapshotAndApplicationEvents.EventTimes(16300, 16800), self.__skill_library.get_skill('Auto', self.__stats.job_class), SkillModifier(), [True, True]),
                 (SnapshotAndApplicationEvents.EventTimes(17440, None), self.__skill_library.get_skill('test_instant_gcd', self.__stats.job_class), SkillModifier(), [True, True]))
 
     result = rb.get_skill_timing().get_q()
@@ -562,7 +562,7 @@ class TestRotationBuilder(TestClass):
                 (SnapshotAndApplicationEvents.EventTimes(7700, 8200), self.__skill_library.get_skill('Auto', self.__stats.job_class), SkillModifier(), [True, True]),
                 (SnapshotAndApplicationEvents.EventTimes(10280, 10780), self.__skill_library.get_skill('Auto', self.__stats.job_class), SkillModifier(), [True, True]),
                 (SnapshotAndApplicationEvents.EventTimes(12860, 13360), self.__skill_library.get_skill('Auto', self.__stats.job_class), SkillModifier(), [True, True]),
-                (SnapshotAndApplicationEvents.EventTimes(15440, 15940), self.__skill_library.get_skill('Auto', self.__stats.job_class), SkillModifier(), [True, True]),
+                (SnapshotAndApplicationEvents.EventTimes(16300, 16800), self.__skill_library.get_skill('Auto', self.__stats.job_class), SkillModifier(), [True, True]),
                 (SnapshotAndApplicationEvents.EventTimes(17440, None), self.__skill_library.get_skill('test_instant_gcd', self.__stats.job_class), SkillModifier(), [True, True]))
 
     result = rb.get_skill_timing().get_q()
